Batteries included: builtin nose plugins
========================================

nose includes a number of builtin plugins that can make testing faster and easier.

.. note ::

   nose 0.11.2 includes a change to default plugin loading. Now, a 3rd party
   plugin with *the same name* as a builtin *will be loaded instead*
   of the builtin plugin.

.. toctree ::
   :maxdepth: 2

   allmodules
   attrib
   capture
   collect
   cover
   debug
   deprecated
   doctests
   failuredetail
   isolate
   logcapture
   multiprocess
   prof
   skip
   testid
   xunit
